﻿using MediatR;
using Netmash.Security.Authentication.Tuitio.Abstractions;
using NetworkResurrector.Api.Domain.Repositories;
using System.Collections.Generic;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;

namespace NetworkResurrector.Api.Application.Queries
{
    public class GetUserPermissions
    {
        public class Query : IRequest<Model> { }

        public class Model
        {
            public IEnumerable<string> Permissions { get; set; }
        }

        public class QueryHandler : IRequestHandler<Query, Model>
        {
            private readonly IUserContextAccessor _userContext;
            private readonly ISecurityRepository _securityRepository;

            public QueryHandler(IUserContextAccessor userContext, ISecurityRepository securityRepository)
            {
                _userContext=userContext;
                _securityRepository=securityRepository;
            }

            public async Task<Model> Handle(Query request, CancellationToken cancellationToken)
            {
                var roles = _userContext.UserRoles.Select(r => r.id);
                var permissions = await _securityRepository.GetUserPermissionCodes(roles);
                return new Model()
                {
                    Permissions = permissions
                };
            }
        }
    }
}
